import sbt._
import Keys._
import PlayProject._

 
 
object MinimalBuild extends Build {
  val SNAPSHOT = "-SNAPSHOT"
 
  val appName = "gatling-test"
  val buildVersion =  "0.0.1-SNAPSHOT"
  val appVersion      = "0.0.1-SNAPSHOT"
  val gatSbtTestVersion = "0.0.1-SNAPSHOT"
 
    lazy val typesafeSnapshot = "Typesafe Snapshots Repository" at "http://repo.typesafe.com/typesafe/snapshots/"
  lazy val typesafe = "Typesafe Repository" at "http://repo.typesafe.com/typesafe/releases/"

    /* OFFICIAL GATLING REPO */
  val gatlingReleasesRepo = "Gatling Releases Repo" at "http://repository.excilys.com/content/repositories/releases"
  val gatling3PartyRepo = "Gatling Third-Party Repo" at "http://repository.excilys.com/content/repositories/thirdparty"
  
   /* LOCAL MAVEN REPO */
  val localMavenRepo = "Local Maven Repository" at file(Path.userHome.absolutePath+"/.m2/repository").toURI.toURL.toString

    
  val cloudbees = "https://repository-andy-petrella.forge.cloudbees.com/"
  val cloudbeesRepo = gatSbtTestVersion match {
      case x if x.endsWith(SNAPSHOT) => x.toLowerCase at cloudbees + "snapshot" + "/"
      case x => x.toLowerCase at cloudbees + "release" + "/"
  }
 /* GATLING DEPS */
  val gatlingVersionNumber = "1.5.2"
  val gatlingApp = "com.excilys.ebi.gatling" % "gatling-app" % gatlingVersionNumber //withSources
  val gatlingCore = "com.excilys.ebi.gatling" % "gatling-core" % gatlingVersionNumber //withSources
  val gatlingHttp = "com.excilys.ebi.gatling" % "gatling-http" % gatlingVersionNumber //withSources
  val gatlingRecorder = "com.excilys.ebi.gatling" % "gatling-recorder" % gatlingVersionNumber //withSources
  val gatlingCharts = "com.excilys.ebi.gatling" % "gatling-charts" % gatlingVersionNumber //withSources
  val gatlingHighcharts = "com.excilys.ebi.gatling.highcharts" % "gatling-charts-highcharts" % gatlingVersionNumber //withSources

 
  val libDependencies = Seq(
    gatlingApp,
    gatlingCore,
    gatlingHttp,
    gatlingRecorder,
    gatlingCharts,
    gatlingHighcharts
  )
 
 lazy val allSettings = 
    Project.defaultSettings ++ 
    Seq(
      version := buildVersion,
      //organization := "be.nextlab",

      resolvers ++= Seq(typesafe, typesafeSnapshot, gatlingReleasesRepo, gatling3PartyRepo, localMavenRepo),
      
      javacOptions += "-Xlint:unchecked",
      
      libraryDependencies ++= libDependencies,
      
      publishMavenStyle := true
      //publishTo := Some(cloudbeesRepo),
      //credentials += cloudbeesCredentials
      
      //commands ++= Seq(gatlingTakatak)//,
      //GatlingPlugin.gatlingResultDir := file(sys.props("java.io.tmpdir")) 
    )
 
  val main = play.Project(appName, appVersion,libDependencies).settings()
}